[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- ziggy.hdmc.code_generator.CodeGenerator
- ziggy.GraphReduce.GraphLoader.GraphLoader: Provides graph handles in Hadoop MapReduce
- object: The most base type
  - ziggy.GraphReduce.PBFS_reducer.BFSNode
  - ziggy.GraphReduce.PBFS_mapper.BFSNode
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.AssertionError: Assertion failed.
  - ziggy.GraphReduce.Degree_mapper.DegreeNode
  - ziggy.GraphReduce.Degree_reducer.DegreeNode
  - ziggy.GraphReduce.LostMass_mapper.PRNode
  - ziggy.GraphReduce.PageRank_mapper.PRNode
  - ziggy.GraphReduce.PageRank_reducer.PRNode
  - unittest.TestCase: A class whose instances are single test cases.
    - ziggy.hdmc.hdmc_tests.HDMCTest